v0.1.4
======

* Fix display of functions in pstats table
* Sort pstats table on total time column be default

v0.1.3
======

* Switch to DataTables for table display
* Store all client assets in distribution for offline use

v0.1.2
======

* ``%snakeviz`` and ``%%snakeviz`` magics for IPython
* Python 3 support
* Fix for tooltips when the cursor is on the right side of the viz
* Remove use of the Bootstrap glyphicons
